@@ -3,17 +3,18 @@
 # Copyright (c), The AiiDA team. All rights reserved.                     #
 # This file is part of the AiiDA code.                                    #
 #                                                                         #
-# The code is hosted on GitHub at https://github.com/aiidateam/aiida_core #
+# The code is hosted on GitHub at https://github.com/aiidateam/aiida-core #
 # For further information on the license, see the LICENSE.txt file        #
 # For further information please visit http://www.aiida.net               #
 ###########################################################################
-from __future__ import unicode_literals
 
-from django.db import models, migrations
-from aiida.backends.djsite.db.migrations import update_schema_version
+from django.db import migrations
+from aiida.backends.djsite.db.migrations import upgrade_schema_version
 
 
-SCHEMA_VERSION = "1.0.6"
+REVISION = '1.0.6'
+DOWN_REVISION = '1.0.5'
+
 
 class Migration(migrations.Migration):
 
@@ -41,6 +42,6 @@ class Migration(migrations.Migration):
             DROP TRIGGER IF EXISTS autoupdate_tc ON db_dblink;
             DROP FUNCTION IF EXISTS update_tc();
         """),
-        update_schema_version(SCHEMA_VERSION)
+        upgrade_schema_version(REVISION, DOWN_REVISION)
 
     ]
