@@ -3,7 +3,7 @@
 # Copyright (c), The AiiDA team. All rights reserved.                     #
 # This file is part of the AiiDA code.                                    #
 #                                                                         #
-# The code is hosted on GitHub at https://github.com/aiidateam/aiida_core #
+# The code is hosted on GitHub at https://github.com/aiidateam/aiida-core #
 # For further information on the license, see the LICENSE.txt file        #
 # For further information please visit http://www.aiida.net               #
 ###########################################################################
@@ -29,7 +29,7 @@ def upgrade():
 
     # I am first migrating the wrongly declared returnlinks out of
     # the InlineCalculations.
-    # This bug is reported #628 https://github.com/aiidateam/aiida_core/issues/628
+    # This bug is reported #628 https://github.com/aiidateam/aiida-core/issues/628
     # There is an explicit check in the code of the inline calculation
     # ensuring that the calculation returns UNSTORED nodes.
     # Therefore, no cycle can be created with that migration!
@@ -42,7 +42,7 @@ def upgrade():
     # 2) set for these links the type to 'createlink'
     stmt1 = text("""
         UPDATE db_dblink set type='createlink' WHERE db_dblink.id IN (
-            SELECT db_dblink_1.id 
+            SELECT db_dblink_1.id
             FROM db_dbnode AS db_dbnode_1
                 JOIN db_dblink AS db_dblink_1 ON db_dblink_1.input_id = db_dbnode_1.id
                 JOIN db_dbnode AS db_dbnode_2 ON db_dblink_1.output_id = db_dbnode_2.id
@@ -53,9 +53,9 @@ def upgrade():
     """)
     conn.execute(stmt1)
     # Now I am updating the link-types that are null because of either an export and subsequent import
-    # https://github.com/aiidateam/aiida_core/issues/685
+    # https://github.com/aiidateam/aiida-core/issues/685
     # or because the link types don't exist because the links were added before the introduction of link types.
-    # This is reported here: https://github.com/aiidateam/aiida_core/issues/687
+    # This is reported here: https://github.com/aiidateam/aiida-core/issues/687
     #
     # The following sql statement:
     # 1) selects all links that
@@ -109,7 +109,7 @@ def upgrade():
             SELECT db_dblink_1.id
             FROM db_dbnode AS db_dbnode_1
                 JOIN db_dblink AS db_dblink_1 ON db_dblink_1.input_id = db_dbnode_1.id
-                JOIN db_dbnode AS db_dbnode_2 ON db_dblink_1.output_id = db_dbnode_2.id 
+                JOIN db_dbnode AS db_dbnode_2 ON db_dblink_1.output_id = db_dbnode_2.id
             WHERE db_dbnode_2.type LIKE 'data.%'
                 AND db_dbnode_1.type = 'calculation.work.WorkCalculation.'
                 AND ( db_dblink_1.type = null OR db_dblink_1.type = '')
@@ -128,7 +128,7 @@ def upgrade():
             SELECT db_dblink_1.id
             FROM db_dbnode AS db_dbnode_1
                 JOIN db_dblink AS db_dblink_1 ON db_dblink_1.input_id = db_dbnode_1.id
-                JOIN db_dbnode AS db_dbnode_2 ON db_dblink_1.output_id = db_dbnode_2.id 
+                JOIN db_dbnode AS db_dbnode_2 ON db_dblink_1.output_id = db_dbnode_2.id
             WHERE db_dbnode_1.type = 'calculation.work.WorkCalculation.'
                 AND db_dbnode_2.type LIKE 'calculation.%'
                 AND ( db_dblink_1.type = null  OR db_dblink_1.type = '')
@@ -138,4 +138,4 @@ def upgrade():
 
 
 def downgrade():
-    print "There is no downgrade for the link types"
+    print('There is no downgrade for the link types')
