@@ -7,15 +7,11 @@
 # For further information on the license, see the LICENSE.txt file        #
 # For further information please visit http://www.aiida.net               #
 ###########################################################################
-
 import os
 
 from aiida.common.exceptions import ValidationError, EntryPointError, InputValidationError
-
 from .data import Data
 
-DEPRECATION_DOCS_URL = 'http://aiida-core.readthedocs.io/en/latest/concepts/processes.html#the-process-builder'
-
 __all__ = ('Code',)
 
 
@@ -173,7 +169,7 @@ class Code(Data):
         :raise aiida.common.MultipleObjectsError: if the string cannot identify uniquely
             a code
         """
-        from aiida.common.exceptions import (NotExistent, MultipleObjectsError, InputValidationError)
+        from aiida.common.exceptions import NotExistent, MultipleObjectsError
         from aiida.orm.querybuilder import QueryBuilder
         from aiida.orm.computers import Computer
 
@@ -185,7 +181,7 @@ class Code(Data):
         if qb.count() == 0:
             raise NotExistent("'{}' is not a valid code name.".format(label))
         elif qb.count() > 1:
-            codes = [_ for [_] in qb.all()]
+            codes = qb.all(flat=True)
             retstr = ("There are multiple codes with label '{}', having IDs: ".format(label))
             retstr += ', '.join(sorted([str(c.pk) for c in codes])) + '.\n'
             retstr += ('Relabel them (using their ID), or refer to them with their ID.')
@@ -212,7 +208,7 @@ class Code(Data):
         from aiida.orm.utils import load_code
 
         # first check if code pk is provided
-        if (pk):
+        if pk:
             code_int = int(pk)
             try:
                 return load_code(pk=code_int)
@@ -222,7 +218,7 @@ class Code(Data):
                 raise MultipleObjectsError("More than one code in the DB with pk='{}'!".format(pk))
 
         # check if label (and machinename) is provided
-        elif (label != None):
+        elif label is not None:
             return cls.get_code_helper(label, machinename)
 
         else:
@@ -276,7 +272,7 @@ class Code(Data):
         from aiida.orm.querybuilder import QueryBuilder
         qb = QueryBuilder()
         qb.append(cls, filters={'attributes.input_plugin': {'==': plugin}})
-        valid_codes = [_ for [_] in qb.all()]
+        valid_codes = qb.all(flat=True)
 
         if labels:
             return [c.label for c in valid_codes]
@@ -491,9 +487,12 @@ class Code(Data):
         return builder
 
     def get_full_text_info(self, verbose=False):
+        """Return a list of lists with a human-readable detailed information on this code.
+
+        :return: list of lists where each entry consists of two elements: a key and a value
         """
-        Return a (multiline) string with a human-readable detailed information on this computer
-        """
+        from aiida.orm.utils.repository import FileType
+
         result = []
         result.append(['PK', self.pk])
         result.append(['UUID', self.uuid])
@@ -508,11 +507,11 @@ class Code(Data):
             result.append(['Type', 'local'])
             result.append(['Exec name', self.get_execname()])
             result.append(['List of files/folders:', ''])
-            for fname in self.list_object_names():
-                if self._repository._get_folder_pathsubfolder.isdir(fname):
-                    result.append(['directory', fname])
+            for obj in self.list_objects():
+                if obj.type == FileType.DIRECTORY:
+                    result.append(['directory', obj.name])
                 else:
-                    result.append(['file', fname])
+                    result.append(['file', obj.name])
         else:
             result.append(['Type', 'remote'])
             result.append(['Remote machine', self.get_remote_computer().name])
@@ -536,7 +535,6 @@ class Code(Data):
 
     @classmethod
     def setup(cls, **kwargs):
-        # raise NotImplementedError
         from aiida.cmdline.commands.code import CodeInputValidationClass
         code = CodeInputValidationClass().set_and_validate_from_code(kwargs)
 
